<?php
namespace bwdsas_anyslide_namespace;

use bwdsas_anyslide_namespace\PageSettings\Page_Settings;
define( "BWDSAS_ASFSK_ASSETS_PUBLIC_DIR_FILE", plugin_dir_url( __FILE__ ) . "assets/public" );
define( "BWDSAS_ASFSK_ASSETS_ADMIN_DIR_FILE", plugin_dir_url( __FILE__ ) . "assets/admin" );
class Classbwdsasswiperslider {

	private static $_instance = null;

	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	public function bwdsas_admin_editor_scripts() {
		add_filter( 'script_loader_tag', [ $this, 'bwdsas_admin_editor_scripts_as_a_module' ], 10, 2 );
	}

	public function bwdsas_admin_editor_scripts_as_a_module( $tag, $handle ) {
		if ( 'bwdsas_swiperslider_editor' === $handle ) {
			$tag = str_replace( '<script', '<script type="module"', $tag );
		}

		return $tag;
	}

	private function include_widgets_files() {
		require_once( __DIR__ . '/widgets/bwdsas-anyslider-widget.php' );
	}

	public function bwdsas_register_widgets() {
		// Its is now safe to include Widgets files
		$this->include_widgets_files();

		// Register WidgetsF
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\bwdsasswiperslider_widgets());
	}

	private function add_page_settings_controls() {
		require_once( __DIR__ . '/page-settings/bwdsas-anyslider-manager.php' );
		new Page_Settings();
	}

	// Register Category
	function bwdsas_add_elementor_widget_categories( $elements_manager ) {

		$elements_manager->add_category(
			'bwdsas-anyslide-category',
			[
				'title' => esc_html__( 'Anything Slide', 'bwdsas-anyslide-td' ),
				'icon' => 'eicon-person',
			]
		);
	}

	//css-js-link-here
	public function bwdsas_all_assets_for_the_public(){

		wp_enqueue_script( 'swiperslider-swiper-interactive', plugin_dir_url( __FILE__ ) . 'assets/public/js/swiper-bundle.min.js', array('jquery'), '1.3', true );

		wp_enqueue_script( 'swiperslider-main', plugin_dir_url( __FILE__ ) . 'assets/public/js/main.js', array('jquery'), '1.3', true );

		$all_css_file = array(

            'swiperslider-plugin-swiper-style' => array('bwdsas_swiperslider_css_path_define'=>BWDSAS_ASFSK_ASSETS_PUBLIC_DIR_FILE . '/css/swiper-bundle.min.css'),

            'swiperslider-plugin-animated' => array('bwdsas_swiperslider_css_path_define'=>BWDSAS_ASFSK_ASSETS_PUBLIC_DIR_FILE . '/css/animate.min.css'),

            'swipersliderplugin-main-style' => array('bwdsas_swiperslider_css_path_define'=>BWDSAS_ASFSK_ASSETS_PUBLIC_DIR_FILE . '/css/main.css'),

        );
        foreach($all_css_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['bwdsas_swiperslider_css_path_define'], null, '1.3', 'all');
        }

	}

	//admin-icon
	public function bwdsas_all_assets_for_elementor_editor_admin(){
		$all_css_js_file = array(
            'swiperslider-admin-main' => array('bwdsas_path_admin_define'=>BWDSAS_ASFSK_ASSETS_ADMIN_DIR_FILE . '/icon.css'),
        );
        foreach($all_css_js_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['bwdsas_path_admin_define'], null, '1.3', 'all');
        }
	}
	
	public function __construct() {

		// For public assets
		add_action('wp_enqueue_scripts', [$this, 'bwdsas_all_assets_for_the_public']);

		// For Elementor Editor
		add_action('elementor/editor/before_enqueue_scripts', [$this, 'bwdsas_all_assets_for_elementor_editor_admin']);
		
		// Register Category
		add_action( 'elementor/elements/categories_registered', [ $this, 'bwdsas_add_elementor_widget_categories' ] );

		// Register widgets
		add_action( 'elementor/widgets/widgets_registered', [ $this, 'bwdsas_register_widgets' ] );

		// Register editor scripts
		add_action( 'elementor/editor/after_enqueue_scripts', [ $this, 'bwdsas_admin_editor_scripts' ] );
		
		$this->add_page_settings_controls();
	}
}

// Instantiate Plugin Class
Classbwdsasswiperslider::instance();